# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.  # noqa: E501

    OpenAPI spec version: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Applicant(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'created_at': 'datetime',
        'delete_at': 'datetime',
        'href': 'str',
        'sandbox': 'bool',
        'title': 'str',
        'first_name': 'str',
        'middle_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'gender': 'str',
        'dob': 'date',
        'telephone': 'str',
        'mobile': 'str',
        'country': 'str',
        'nationality': 'str',
        'mothers_maiden_name': 'str',
        'country_of_birth': 'str',
        'town_of_birth': 'str',
        'previous_last_name': 'str',
        'addresses': 'list[Address]',
        'id_numbers': 'list[IdNumber]'
    }

    attribute_map = {
        'id': 'id',
        'created_at': 'created_at',
        'delete_at': 'delete_at',
        'href': 'href',
        'sandbox': 'sandbox',
        'title': 'title',
        'first_name': 'first_name',
        'middle_name': 'middle_name',
        'last_name': 'last_name',
        'email': 'email',
        'gender': 'gender',
        'dob': 'dob',
        'telephone': 'telephone',
        'mobile': 'mobile',
        'country': 'country',
        'nationality': 'nationality',
        'mothers_maiden_name': 'mothers_maiden_name',
        'country_of_birth': 'country_of_birth',
        'town_of_birth': 'town_of_birth',
        'previous_last_name': 'previous_last_name',
        'addresses': 'addresses',
        'id_numbers': 'id_numbers'
    }

    def __init__(self, id=None, created_at=None, delete_at=None, href=None, sandbox=None, title=None, first_name=None, middle_name=None, last_name=None, email=None, gender=None, dob=None, telephone=None, mobile=None, country=None, nationality=None, mothers_maiden_name=None, country_of_birth=None, town_of_birth=None, previous_last_name=None, addresses=None, id_numbers=None):  # noqa: E501
        """Applicant - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._created_at = None
        self._delete_at = None
        self._href = None
        self._sandbox = None
        self._title = None
        self._first_name = None
        self._middle_name = None
        self._last_name = None
        self._email = None
        self._gender = None
        self._dob = None
        self._telephone = None
        self._mobile = None
        self._country = None
        self._nationality = None
        self._mothers_maiden_name = None
        self._country_of_birth = None
        self._town_of_birth = None
        self._previous_last_name = None
        self._addresses = None
        self._id_numbers = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if created_at is not None:
            self.created_at = created_at
        if delete_at is not None:
            self.delete_at = delete_at
        if href is not None:
            self.href = href
        if sandbox is not None:
            self.sandbox = sandbox
        if title is not None:
            self.title = title
        if first_name is not None:
            self.first_name = first_name
        if middle_name is not None:
            self.middle_name = middle_name
        if last_name is not None:
            self.last_name = last_name
        if email is not None:
            self.email = email
        if gender is not None:
            self.gender = gender
        if dob is not None:
            self.dob = dob
        if telephone is not None:
            self.telephone = telephone
        if mobile is not None:
            self.mobile = mobile
        if country is not None:
            self.country = country
        if nationality is not None:
            self.nationality = nationality
        if mothers_maiden_name is not None:
            self.mothers_maiden_name = mothers_maiden_name
        if country_of_birth is not None:
            self.country_of_birth = country_of_birth
        if town_of_birth is not None:
            self.town_of_birth = town_of_birth
        if previous_last_name is not None:
            self.previous_last_name = previous_last_name
        if addresses is not None:
            self.addresses = addresses
        if id_numbers is not None:
            self.id_numbers = id_numbers

    @property
    def id(self):
        """Gets the id of this Applicant.  # noqa: E501

        The unique identifier for the applicant. Read-only.  # noqa: E501

        :return: The id of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Applicant.

        The unique identifier for the applicant. Read-only.  # noqa: E501

        :param id: The id of this Applicant.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def created_at(self):
        """Gets the created_at of this Applicant.  # noqa: E501

        The date and time when this applicant was created. Read-only.  # noqa: E501

        :return: The created_at of this Applicant.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Applicant.

        The date and time when this applicant was created. Read-only.  # noqa: E501

        :param created_at: The created_at of this Applicant.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def delete_at(self):
        """Gets the delete_at of this Applicant.  # noqa: E501

        The date and time when this applicant is scheduled to be deleted. Read-only.  # noqa: E501

        :return: The delete_at of this Applicant.  # noqa: E501
        :rtype: datetime
        """
        return self._delete_at

    @delete_at.setter
    def delete_at(self, delete_at):
        """Sets the delete_at of this Applicant.

        The date and time when this applicant is scheduled to be deleted. Read-only.  # noqa: E501

        :param delete_at: The delete_at of this Applicant.  # noqa: E501
        :type: datetime
        """

        self._delete_at = delete_at

    @property
    def href(self):
        """Gets the href of this Applicant.  # noqa: E501

        The uri of this resource. Read-only.  # noqa: E501

        :return: The href of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this Applicant.

        The uri of this resource. Read-only.  # noqa: E501

        :param href: The href of this Applicant.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def sandbox(self):
        """Gets the sandbox of this Applicant.  # noqa: E501

        Read-only.  # noqa: E501

        :return: The sandbox of this Applicant.  # noqa: E501
        :rtype: bool
        """
        return self._sandbox

    @sandbox.setter
    def sandbox(self, sandbox):
        """Sets the sandbox of this Applicant.

        Read-only.  # noqa: E501

        :param sandbox: The sandbox of this Applicant.  # noqa: E501
        :type: bool
        """

        self._sandbox = sandbox

    @property
    def title(self):
        """Gets the title of this Applicant.  # noqa: E501

        The applicant’s title  # noqa: E501

        :return: The title of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Applicant.

        The applicant’s title  # noqa: E501

        :param title: The title of this Applicant.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def first_name(self):
        """Gets the first_name of this Applicant.  # noqa: E501

        The applicant’s first name  # noqa: E501

        :return: The first_name of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this Applicant.

        The applicant’s first name  # noqa: E501

        :param first_name: The first_name of this Applicant.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def middle_name(self):
        """Gets the middle_name of this Applicant.  # noqa: E501

        The applicant’s middle name(s) or initial  # noqa: E501

        :return: The middle_name of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._middle_name

    @middle_name.setter
    def middle_name(self, middle_name):
        """Sets the middle_name of this Applicant.

        The applicant’s middle name(s) or initial  # noqa: E501

        :param middle_name: The middle_name of this Applicant.  # noqa: E501
        :type: str
        """

        self._middle_name = middle_name

    @property
    def last_name(self):
        """Gets the last_name of this Applicant.  # noqa: E501

        The applicant’s surname  # noqa: E501

        :return: The last_name of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this Applicant.

        The applicant’s surname  # noqa: E501

        :param last_name: The last_name of this Applicant.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this Applicant.  # noqa: E501

        The applicant’s email address. Required if doing a US check or a standard UK check.  # noqa: E501

        :return: The email of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Applicant.

        The applicant’s email address. Required if doing a US check or a standard UK check.  # noqa: E501

        :param email: The email of this Applicant.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def gender(self):
        """Gets the gender of this Applicant.  # noqa: E501

        The applicant’s gender. Valid values are male and female.  # noqa: E501

        :return: The gender of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._gender

    @gender.setter
    def gender(self, gender):
        """Sets the gender of this Applicant.

        The applicant’s gender. Valid values are male and female.  # noqa: E501

        :param gender: The gender of this Applicant.  # noqa: E501
        :type: str
        """

        self._gender = gender

    @property
    def dob(self):
        """Gets the dob of this Applicant.  # noqa: E501

        The applicant’s date of birth  # noqa: E501

        :return: The dob of this Applicant.  # noqa: E501
        :rtype: date
        """
        return self._dob

    @dob.setter
    def dob(self, dob):
        """Sets the dob of this Applicant.

        The applicant’s date of birth  # noqa: E501

        :param dob: The dob of this Applicant.  # noqa: E501
        :type: date
        """

        self._dob = dob

    @property
    def telephone(self):
        """Gets the telephone of this Applicant.  # noqa: E501

        The applicant’s landline phone number  # noqa: E501

        :return: The telephone of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._telephone

    @telephone.setter
    def telephone(self, telephone):
        """Sets the telephone of this Applicant.

        The applicant’s landline phone number  # noqa: E501

        :param telephone: The telephone of this Applicant.  # noqa: E501
        :type: str
        """

        self._telephone = telephone

    @property
    def mobile(self):
        """Gets the mobile of this Applicant.  # noqa: E501

        The applicant’s mobile phone number  # noqa: E501

        :return: The mobile of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._mobile

    @mobile.setter
    def mobile(self, mobile):
        """Sets the mobile of this Applicant.

        The applicant’s mobile phone number  # noqa: E501

        :param mobile: The mobile of this Applicant.  # noqa: E501
        :type: str
        """

        self._mobile = mobile

    @property
    def country(self):
        """Gets the country of this Applicant.  # noqa: E501

        The country where this applicant will be checked. This must be a three-letter ISO code e.g. GBR or USA  # noqa: E501

        :return: The country of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this Applicant.

        The country where this applicant will be checked. This must be a three-letter ISO code e.g. GBR or USA  # noqa: E501

        :param country: The country of this Applicant.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def nationality(self):
        """Gets the nationality of this Applicant.  # noqa: E501

        The applicant's nationality. This must be a three-letter ISO code e.g. GBR or USA  # noqa: E501

        :return: The nationality of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._nationality

    @nationality.setter
    def nationality(self, nationality):
        """Sets the nationality of this Applicant.

        The applicant's nationality. This must be a three-letter ISO code e.g. GBR or USA  # noqa: E501

        :param nationality: The nationality of this Applicant.  # noqa: E501
        :type: str
        """

        self._nationality = nationality

    @property
    def mothers_maiden_name(self):
        """Gets the mothers_maiden_name of this Applicant.  # noqa: E501

        The applicant’s mothers maiden name  # noqa: E501

        :return: The mothers_maiden_name of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._mothers_maiden_name

    @mothers_maiden_name.setter
    def mothers_maiden_name(self, mothers_maiden_name):
        """Sets the mothers_maiden_name of this Applicant.

        The applicant’s mothers maiden name  # noqa: E501

        :param mothers_maiden_name: The mothers_maiden_name of this Applicant.  # noqa: E501
        :type: str
        """

        self._mothers_maiden_name = mothers_maiden_name

    @property
    def country_of_birth(self):
        """Gets the country_of_birth of this Applicant.  # noqa: E501

        The applicant’s country of birth  # noqa: E501

        :return: The country_of_birth of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._country_of_birth

    @country_of_birth.setter
    def country_of_birth(self, country_of_birth):
        """Sets the country_of_birth of this Applicant.

        The applicant’s country of birth  # noqa: E501

        :param country_of_birth: The country_of_birth of this Applicant.  # noqa: E501
        :type: str
        """

        self._country_of_birth = country_of_birth

    @property
    def town_of_birth(self):
        """Gets the town_of_birth of this Applicant.  # noqa: E501

        The applicant’s town of birth  # noqa: E501

        :return: The town_of_birth of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._town_of_birth

    @town_of_birth.setter
    def town_of_birth(self, town_of_birth):
        """Sets the town_of_birth of this Applicant.

        The applicant’s town of birth  # noqa: E501

        :param town_of_birth: The town_of_birth of this Applicant.  # noqa: E501
        :type: str
        """

        self._town_of_birth = town_of_birth

    @property
    def previous_last_name(self):
        """Gets the previous_last_name of this Applicant.  # noqa: E501

        The applicant’s previous last name  # noqa: E501

        :return: The previous_last_name of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._previous_last_name

    @previous_last_name.setter
    def previous_last_name(self, previous_last_name):
        """Sets the previous_last_name of this Applicant.

        The applicant’s previous last name  # noqa: E501

        :param previous_last_name: The previous_last_name of this Applicant.  # noqa: E501
        :type: str
        """

        self._previous_last_name = previous_last_name

    @property
    def addresses(self):
        """Gets the addresses of this Applicant.  # noqa: E501


        :return: The addresses of this Applicant.  # noqa: E501
        :rtype: list[Address]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """Sets the addresses of this Applicant.


        :param addresses: The addresses of this Applicant.  # noqa: E501
        :type: list[Address]
        """

        self._addresses = addresses

    @property
    def id_numbers(self):
        """Gets the id_numbers of this Applicant.  # noqa: E501


        :return: The id_numbers of this Applicant.  # noqa: E501
        :rtype: list[IdNumber]
        """
        return self._id_numbers

    @id_numbers.setter
    def id_numbers(self, id_numbers):
        """Sets the id_numbers of this Applicant.


        :param id_numbers: The id_numbers of this Applicant.  # noqa: E501
        :type: list[IdNumber]
        """

        self._id_numbers = id_numbers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Applicant):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
