# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.  # noqa: E501

    OpenAPI spec version: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import onfido
from onfido.models.report import Report  # noqa: E501
from onfido.rest import ApiException


class TestReport(unittest.TestCase):
    """Report unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReport(self):
        """Test Report"""
        # FIXME: construct object with mandatory attributes with example values
        # model = onfido.models.report.Report()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
